@@ -4,7 +4,7 @@ from ..array import Array
 
 def Padding(size):
     class Padding(Array(uint8_t, size)):
-        FORMAT = '{0}B'.format(size)
+        FORMAT = f'{size}B'
 
         def __bytes__(self):
             return b''.join(self)
